/***********************************************************************
 *
 * Copyright (C) 2004 by FS Forth-Systeme GmbH.
 * All rights reserved.
 *
 * $Id: ns9750_pci.h,v 1.2 2005/09/06 07:35:00 uzeisberger Exp $
 * @Author: Markus Pietrek
 * @Descr: Definitions for SYS Control Module
 * @References: [1] NS9750 Hardware Reference Manual/December 2003 Chap. 4
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 *
 *
 ***********************************************************************/
/***********************************************************************
 *  @History:
 ***********************************************************************/

#ifndef FS_NS9750_PCI_H
#define FS_NS9750_PCI_H

/* These addresses are derived from information contained in
 * .../arch/arm/mach-ns9750/core.c:61 which defines the
 * core hardware mappings between kernel virtual addresses
 * and ns9750-defined physical addresses.
 */
/* The base address of the AHB-PCI bridge (virtual) */
#define NS_PCI_MODULE_BASE		(0xFA300000)

/* The base address of PCI memory space (virtual)
 * physical limits: 256MB starting at 0x80000000
 * Current limit: 16MB
 */
#define NS_PCI_MEM_BASE			(0xF8000000)

/* The base address of the PCI I/O space (virtual)
 * physical limits: 1 Mbyte
 */
#define NS_PCI_IO_BASE			(0xFA000000)

/* The address of PCI config space address register */
#define NS_PCI_CONFIG_ADDR		(0xFA100000)

/* The address of PCI config space data register */
#define NS_PCI_CONFIG_DATA		(0xFA200000)

/* The */

/* the register addresses */
#define NS_PCI_PARBCFG			(NS_PCI_MODULE_BASE + 0x0000)
#define NS_PCI_PARBINT			(NS_PCI_MODULE_BASE + 0x0004)
#define NS_PCI_PARBINTEN		(NS_PCI_MODULE_BASE + 0x0008)
#define NS_PCI_PMISC			(NS_PCI_MODULE_BASE + 0x000C)
#define NS_PCI_PCFG0			(NS_PCI_MODULE_BASE + 0x0010)
#define NS_PCI_PCFG1			(NS_PCI_MODULE_BASE + 0x0014)
#define NS_PCI_PCFG2			(NS_PCI_MODULE_BASE + 0x0018)
#define NS_PCI_PCFG3			(NS_PCI_MODULE_BASE + 0x001C)
#define NS_PCI_PAHBCFG			(NS_PCI_MODULE_BASE + 0x0020)
#define NS_PCI_PAHBERR			(NS_PCI_MODULE_BASE + 0x0024)
#define NS_PCI_PCIERR			(NS_PCI_MODULE_BASE + 0x0028)
#define NS_PCI_PINTR			(NS_PCI_MODULE_BASE + 0x002C)
#define NS_PCI_PINTEN			(NS_PCI_MODULE_BASE + 0x0030)
#define NS_PCI_PALTMEM0			(NS_PCI_MODULE_BASE + 0x0034)
#define NS_PCI_PALTMEM1			(NS_PCI_MODULE_BASE + 0x0038)
#define NS_PCI_PALTIO			(NS_PCI_MODULE_BASE + 0x003C)
#define NS_PCI_PMALT0			(NS_PCI_MODULE_BASE + 0x0040)
#define NS_PCI_PMALT1			(NS_PCI_MODULE_BASE + 0x0044)
#define NS_PCI_PALTCTL			(NS_PCI_MODULE_BASE + 0x0048)
#define NS_PCI_CMISC			(NS_PCI_MODULE_BASE + 0x004c)
#define NS_PCI_CSKTEV			(NS_PCI_MODULE_BASE + 0x1000)
#define NS_PCI_CSKTMSK			(NS_PCI_MODULE_BASE + 0x1004)
#define NS_PCI_CSKTPST			(NS_PCI_MODULE_BASE + 0x1008)
#define NS_PCI_CSKTFEV			(NS_PCI_MODULE_BASE + 0x100C)
#define NS_PCI_CSKTCTL			(NS_PCI_MODULE_BASE + 0x1010)

/* NS_PCI_PARBCFG: PCI Arbiter Configuration Register */
#define NS_PCI_PCI_CTL_RSC	0x0001
#define NS_PCI_PCIEN_M1		0x0002
#define NS_PCI_PCIEN_M2		0x0004
#define NS_PCI_PCIEN_M3		0x0008

/* NS_PCI_PARBINT: PCI Arbiter Interrupt Status Register */
#define NS_PCI_PCIBRK_M0	0x0001
#define NS_PCI_PCIBRK_M1	0x0002
#define NS_PCI_PCIBRK_M2	0x0004
#define NS_PCI_PCIBRK_M3	0x0008
#define NS_PCI_PCISERR		0x0010
#define NS_PCI_CCLKRUN		0x0020

/* NS_PCI_PARBINTEN: PCI Arbiter Interrupt Enable Register */
#define NS_PCI_EN_PBRK_M0	0x0001
#define NS_PCI_EN_PBRK_M1	0x0002
#define NS_PCI_EN_PBRK_M2	0x0004
#define NS_PCI_EN_PBRK_M3	0x0008
#define NS_PCI_EN_PCISERR	0x0010
#define NS_PCI_EN_CCLKRUN	0x0020

/* NS_PCI_PMISC: PCI Miscellaneous Support Register */
#define NS_PCI_INTA2PCI		0x0001
#define NS_PCI_EN_BAR0		0x0010
#define NS_PCI_EN_BAR1		0x0020
#define NS_PCI_EN_BAR2		0x0040
#define NS_PCI_EN_BAR3		0x0080
#define NS_PCI_EN_BAR4		0x0100
#define NS_PCI_EN_BAR5		0x0200

/* NS_PCI_PCFG0: PCI Configuration 0 register */
#define NS_PCI_DEVICE_ID_MSK	0xFFFF		/* 16 bits */
#define NS_PCI_DEVICE_ID_SH	16		/* shift */
#define NS_PCI_VENDOR_ID_MSK	0xFFFF		/* Mask */
#define NS_PCI_VENDOR_ID_SH	0		/* shift */

/* NS_PCI_PCFG1: PCI Configuration 1 register */
#define NS_PCI_CLASS_CODE_MSK	0xFFFFFF	/* 24 bits */
#define NS_PCI_CLASS_CODE_SH	8		/* shift */
#define NS_PCI_REVISION_ID_MSK	0xFF		/* 8 bits */
#define NS_PCI_REVISION_ID_SH	0		/* shift */

/* NS_PCI_PCFG2: PCI Configuration 2 register */
#define NS_PCI_SUBSYSTEM_ID_MSK	0xFFFF		/* 16 bits */
#define NS_PCI_SUBSYSTEM_ID_SH	16		/* shift */
#define NS_PCI_SUBVENDOR_ID_MSK	0xFFFF		/* Mask */
#define NS_PCI_SUBVENDOR_ID_SH	0		/* shift */

/* NS_PCI_PCFG3: PCI Configuration 3 register */
#define NS_PCI_MAX_LATENCY_MSK	0xFF		/* 8 bits */
#define NS_PCI_MAX_LATENCY_SH	16		/* shift */
#define NS_PCI_MIN_GRANT_MSK	0xFF		/* 8 bits */
#define NS_PCI_MIN_GRANT_SH	8		/* shift */
#define NS_PCI_INTERRUPT_PIN_MSK	0xFF	/* 8 bits */
#define NS_PCI_INTERRUPT_PIN_SH		0	/* shift */

/* NS_PCI_AHBCFG: PCI Bridge Configuration register */
#define NS_PCI_AHBBRST_MSK	0x3		/* 2 bits */
#define NS_PCI_AHBBRST_SH	0		/* shift */

#define NS_PCI_AHBBRST_16	0	/* 16 cycles */
#define NS_PCI_AHBBRST_32	1	/* 32 cycles */
#define NS_PCI_AHBBRST_64	2	/* 16 cycles */
/* value "3" is reserved */

/* NS_PCI_AHBERR: PCI Bridge AHB Error Address register */
/* 32-bit address register */

/* NS_PCI_PCIERR: PCI Bridge PCI Error Address register */
/* 32-bit address register */

/* NS_PCI_PINTR: PCI Interrupt Status Register */
#define NS_PCI_AHBERR		0x0001

/* NS_PCI_PINTEN: PCI Bridge Interrupt Enable Register */
#define NS_PCI_AHBERREN		0x0001
#define NS_PCI_PMPERREN		0x0100
#define NS_PCI_SIGTAEN		0x0800
#define NS_PCI_PRXTARN		0x1000
#define NS_PCI_PRXMAEN		0x2000
#define NS_PCI_PSYSEREN		0x4000
#define NS_PCI_PDPERREN		0x8000

/* NS_PCI_PALTMEM0: PCI Bridge AHB-to-PCI Addr Translate 0 */
#define NS_PCI_PALTxVAL_MSK	0x7F	/* 7 bits */
#define NS_PCI_PALT0VAL_SH	0	/* shift */
#define NS_PCI_PALT1VAL_SH	8	/* shift */
#define NS_PCI_PALT2VAL_SH	16	/* shift */
#define NS_PCI_PALT3VAL_SH	24	/* shift */

/* NS_PCI_PALTMEM1: PCI Bridge AHB-to-PCI Addr Translate 1 */
#define NS_PCI_PALT4VAL_SH	0	/* shift */
#define NS_PCI_PALT5VAL_SH	8	/* shift */
#define NS_PCI_PALT6VAL_SH	16	/* shift */
#define NS_PCI_PALT7VAL_SH	24	/* shift */

/* NS_PCI_PALTIO: PCI Bridge AHB_to-PCI I/O Addr Translate */
#define NS_PCI_PALT8VAL_MSK	0xFFF	/* 12 bits */
#define NS_PCI_PALT8VAL_SH	0	/* shift */

/* NS_PCI_PMALT0: PCI Bridge PCI-to-AHB Addr Translage 0 */
#define NS_PCI_MALT0VAL_MSK	0xF	/* 4 bits */
#define NS_PCI_MALT0VAL_SH	0	/* shift */
#define NS_PCI_MALT1VAL_MSK	0x3F	/* 6 bits */
#define NS_PCI_MALT1VAL_SH	4	/* shift */
#define NS_PCI_MALT2VAL_MSK	0xFF	/* 8 bits */
#define NS_PCI_MALT2VAL_SH	12	/* shift */
#define NS_PCI_MALT3VAL_MSK	0x3FF	/* 10 bits */
#define NS_PCI_MALT3VAL_SH	20	/* shift */

/* NS_PCI_PMALT1: PCI Bridge PCI-to-AHB Addr Translage 1 */
#define NS_PCI_MALT4VAL_MSK	0xFFF	/* 12 bits */
#define NS_PCI_MALT4VAL_SH	0	/* shift */
#define NS_PCI_MALT5VAL_MSK	0x3FF	/* 10 bits */
#define NS_PCI_MALT5VAL_SH	16	/* shift */

/* NS_PCI_PALTCTL: PCI Address Translation Control Register */
#define NS_PCI_PALT_EN		0x0001
#define NS_PCI_MALT_EN		0x0002


#endif /* FS_NS9750_PCI_H */
